controller_ping (zotonic_mod_base v1.0.0-rc.17)

Simple controller for connection tests, used on the /test/connection page.

It always responds with the four character string pong. The ususal path is: /.zotonic/ping

Summary

Functions

content_types_provided(Context)

process/4