controller_website_redirect (zotonic_mod_base v1.0.0-rc.17)
This controller does a redirect to the website property of the given resource.
Todo
Extend documentation
This controller does a redirect to the website property of the given resource.
Todo
Extend documentation