filter_default_if_none (zotonic_mod_base v1.0.0-rc.17)
Provide an alternative value in case a value is undefined.
For example:
{{ value|default_if_none:1 }}Same as default_if_undefined.
This filter is built-in in the template compiler and inlined when compiling templates.
See also