filter_default_if_undefined (zotonic_mod_base v1.0.0-rc.17)

Provide an alternative value in case a value is undefined.

For example:

{{ value|default_if_undefined:1 }}

Same as default_if_none.

This filter is built-in in the template compiler and inlined when compiling templates.

See also

default, if, is_defined, is_undefined, if_undefined

Summary

Functions

default_if_undefined/3