filter_is_defined (zotonic_mod_base v1.0.0-rc.17)

Tests if a value is defined.

Checks if the value is not empty and outputs a boolean true or false. This is useful in combination with the if tag.

For example:

{% if value|is_defined %}The value was defined{% endif %}

When the value is “foo” then the output “The value was defined”.

See also

is_undefined, if_undefined, if

Summary

Functions

is_defined/2