filter_is_not_a (zotonic_mod_base v1.0.0-rc.17)

is_not_a mirrors is_a. It is particularly useful when iterating over a category and excluding members of a sub-category (iterating over all images associated with a page except images in the thumbnail category).

Example for looping over all media in a rsc but excluding the thumbnail resources:

{% for m in m.rsc[id].media|is_not_a:"thumbnail" %}
...
{% endfor %}

See also

is_a, is_visible, filter

Summary

Functions

is_not_a/3

is_not_a(List, Cat, N, Context)