filter_min (zotonic_mod_base v1.0.0-rc.17)
Take the minimum of the filter value and its first argument.
Usage with two values
Take the maximum of the filter value and its first argument.
{% print 102 | to_integer | max:103 %}Prints 102.
Usage with two values
Take the minimum of the filter value and its first argument::
{{ 102 | min:103 }}
Prints 103.
Usage with lists
Find the minimum value in a list::
{% print [1, 5, 3, 9, 2] | min %}Prints 1.
Edge cases
undefined | minreturnsundefinedundefined | min:1000returnsundefined[] | max(empty list) returnsundefined- Works with translation tuple values.
See also