filter_rjust (zotonic_mod_base v1.0.0-rc.17)
Justifies the value in a field of a certain width to the right, using spaces.
For example:
{{ value|rjust:7 }}When value is hello then the output is __hello (with spaces).
Justifying only works for single byte character values. At this moment there is no support for multi-byte unicode characters.
See also