filter_split (zotonic_mod_base v1.0.0-rc.17)

Splits the filter value into a list of values.

The input value is split by the filter argument, for example:

{{ "foo bar baz"|split:" " }}

Will create the list ["foo", "bar", "baz"].

See also

join

Summary

Functions

split/3