filter_stringify (zotonic_mod_base v1.0.0-rc.17)

Translates atoms, integers and floats to strings. The undefined value is translated to the empty string. Does not translate tuples.

For example:

{{ value|stringify }}

When value is undefined then the output will be “”.

See also

slugify, to_binary

Summary

Functions

stringify/2