filter_url_abs (zotonic_mod_base v1.0.0-rc.17)

Generates an absolute URL for the given dispatch information.

An absolute URL is an URL that includes the protcol and hostname. For example https://example.com/foo/bar.

For example, generate a url for the dispatch rule home with an extra argument hello:

{{ {home hello="world"}|url_abs }}

This is similar to:

{% url_abs home hello="world" %}

Difference between the tag and the filter is that the filter can be used in expressions or with passed values.

See also

url, url, sanitize_url, is_site_url, urlencode

Summary

Functions

url_abs/2