validator_base_confirmation (zotonic_mod_base v1.0.0-rc.17)

Check if two inputs are the same.

Useful when a form requires double entry of a password or e-mail address to prevent typos.

Accepts an additional parameter name with the name of the other input field.

For example:

<input type="password" id="password" name="password" value="" />
<input type="password" id="password2" name="password2" value="" />
{% validate id="password" type={confirmation match="password2"} %}

Arguments

ArgumentDescriptionExample
matchThe id of the input field that should have the same value.match="field1"
failure\_messageMessage to be shown when the two fields are unequal. Defaults to “Does not match.”failure_message="Please retry."

See also

Forms and validation

Summary

Functions

render_validator/5

validate/5

-spec validate(term(), term(), term(), list(), z:context()) ->
                  {{ok, term()}, z:context()} | {{error, term(), term()}, z:context()}.