filter_after (zotonic_mod_base v1.0.0-rc.17)
Return the first element after another element in a list. For example:
{{ [1,2,3]|after:2 }}Evaluates to the value 3.
If the element is not part of the list, or is the last element in the list, the returned value is undefined.