filter_is_undefined (zotonic_mod_base v1.0.0-rc.17)
Tests if a value is undefined.
Checks if the value is empty and outputs a boolean true or false. This is useful in combination with the if tag.
For example:
{% if value[1]|is_undefined %}The first elemeent of value was undefined{% endif %}If the value is [] then the output is The first elemeent of value was undefined.
See also