filter_match (zotonic_mod_base v1.0.0-rc.17)
Match a value with a regular expression.
Returns true if the value matches the regular expression. This is handy for checking if a string starts or ends with a particular value.
Usage:
{% if value|match:".*foo$" %}Checks if the value ends with “foo”.