filter_urldecode (zotonic_mod_base v1.0.0-rc.17)
Decode a text where characters are encoded as URL-safe characters.
Translates all percent encoded characters back to their original encoding.
For example:
{{ value|urldecode }}When value is “msg%3DHello%26World” then the output is “msg=Hello&World”.
See also